# aria_client

This is a simple wrapper around the client side REST api for the multi message-transport ARIA platform.

Build instructions
==================

pip install -r requirements_dev.txt
python -m build

Then to upload into pyi 
twine upload dist/*